@@ -106,7 +106,7 @@ class TrellisImageTo3DPipeline(Pipeline):
             if scale < 1:
                 input = input.resize((int(input.width * scale), int(input.height * scale)), Image.Resampling.LANCZOS)
             if getattr(self, 'rembg_session', None) is None:
-                os.environ['U2NET_HOME'] = self.path
+                os.environ['U2NET_HOME'] = str(self.path)
                 self.rembg_session = rembg.new_session('u2net')
             output = rembg.remove(input, session=self.rembg_session)
         output_np = np.array(output)
